package events;

import org.orekit.errors.OrekitException;
import org.orekit.propagation.events.EventDetector.Action;
import org.orekit.time.AbsoluteDate;
import org.orekit.time.TimeScalesFactory;

import fr.cnes.genius.exception.GComponentListException;
import fr.cnes.genius.exception.GException;
import fr.cnes.genius.highLevel.GComboBoxWithLabel;
import fr.cnes.genius.lowLevel.GPanel;
import fr.cnes.genius.main.GReadWrite;
import fr.cnes.genius.utils.GPanTest;
import fr.cnes.genopus.events.GPAOLDetector;
import fr.cnes.genopus.events.GPAltitudeDetector;
import fr.cnes.genopus.events.GPApsideDetector;
import fr.cnes.genopus.events.GPDateDetector;
import fr.cnes.genopus.events.GPEclipseDetector;
import fr.cnes.genopus.events.GPLocalTimeDetector;
import fr.cnes.genopus.events.GPNodeDetector;
import fr.cnes.genopus.events.GPRelativeDateDetector;
import fr.cnes.genopus.events.GPVisibilityFromStationDetector;
import fr.cnes.genopus.nonWidget.events.CustomDateDetector;
import fr.cnes.sirius.addons.patriusdataset.PatriusDataset;

/**
 * Tutorial for using GPEvents.
 * @author goesterjf
 *
 */
public class TestGPEvents extends GPanel implements GReadWrite{
    
    private final GComboBoxWithLabel choice;
    
    private final GPDateDetector date;
    private final GPRelativeDateDetector rel;
    private final GPAltitudeDetector alt;
    
    private final GPAOLDetector aol;
    
    private final GPApsideDetector aps;
    private final GPEclipseDetector ecl;
    private final GPLocalTimeDetector loc;
    private final GPNodeDetector nod;
    private final GPVisibilityFromStationDetector vis;

    
    public TestGPEvents() throws GComponentListException, IllegalArgumentException, OrekitException {

        final String[] listOfEvents = { "Absolute date", "Relative date", "Altitude", "AOL", "Apside", "Eclipse", "Local time", "Node", "Visibility" };
        choice = new GComboBoxWithLabel("Type of event", 0, listOfEvents);
        
        final AbsoluteDate date0 = new AbsoluteDate(2010, 1, 1, TimeScalesFactory.getUTC());
        final CustomDateDetector dateDetector = new CustomDateDetector(date0);
        date = new GPDateDetector("Absolute date event", dateDetector, Action.RESET_STATE, Action.RESET_DERIVATIVES);
        //date.blockAction(Action.STOP);
        
        rel = new GPRelativeDateDetector("Realtive date event", Action.STOP);
        alt = new GPAltitudeDetector("Altitude detector");
        
        aol = new GPAOLDetector("AOL detector");
        aps = new GPApsideDetector("Aspide detector");
        ecl = new GPEclipseDetector("Eclipse detector");
        loc = new GPLocalTimeDetector("Local time detector");
        nod = new GPNodeDetector("Node detector");
        vis = new GPVisibilityFromStationDetector("Visibility detector");
        
    }

    @Override
    public void generic() throws GException {
        put(choice);
        switch (choice.getValue()) {
        case 0:
            put(date);
            break;
        case 1:
            put(rel);
            break;
        case 2:
            put(alt);
            break;
        case 3:
            put(aol);
            break;
        case 4:
            put(aps);
            break;
        case 5:
            put(ecl);
            break;
        case 6:
            put(loc);
            break;
        case 7:
            put(nod);
            break;
        case 8:
            put(vis);
            break;
        default:
            break;
        }
    }

    public void display() throws GException {
        generic();
    }

    public void read() throws GException {
        generic();
    }

    public void write() throws GException {
        generic();
    }

    /**
     * @param args
     * @throws OrekitException 
     * @throws GComponentListException 
     */
    public static void main(String[] args) throws OrekitException, GComponentListException {
        
        PatriusDataset.addResourcesFromPatriusDataset() ;

        GPanTest panTest = new GPanTest("Events", new TestGPEvents(), "GPEvents.xml");
        panTest.display();


    }


}
