package vehicle;
import java.util.ArrayList;

import org.orekit.errors.OrekitException;

import fr.cnes.genius.exception.GException;
import fr.cnes.genius.lowLevel.GPanel;
import fr.cnes.genius.main.GReadWrite;
import fr.cnes.genius.utils.GPanTest;
import fr.cnes.genopus.nonWidget.maneuvers.CustomEngine;
import fr.cnes.genopus.nonWidget.maneuvers.CustomFuelTank;
import fr.cnes.genopus.nonWidget.vehicle.CustomAerodynamicProperties;
import fr.cnes.genopus.nonWidget.vehicle.CustomVehicle;
import fr.cnes.genopus.nonWidget.vehicle.CustomVehicleSurfaceModel;
import fr.cnes.genopus.nonWidget.vehicle.geometry.CustomParallelepiped;
import fr.cnes.genopus.vehicle.GPVehicle;
import fr.cnes.sirius.addons.patriusdataset.PatriusDataset;
import fr.cnes.sirius.patrius.assembly.properties.MassProperty;

/**
 * Tutorial for using GPVehicle with initialization using CustomVehicle.
 * @author goesterjf
 *
 */
public class TestGPVehicleWithInit extends GPanel implements GReadWrite {
    
    private final GPVehicle veh;
    
    public TestGPVehicleWithInit () {
        
        // DRY MASS
        final double dryMass = 1000.;
        MassProperty dryMassProperty = null;
        try {
            dryMassProperty = new MassProperty(dryMass);
        } catch (OrekitException err) {
            err.printStackTrace();
        }
        
        // PROPULSION
        final ArrayList<CustomEngine> enginesList = new ArrayList<CustomEngine>();
        enginesList.add(new CustomEngine("OCS", 320., 1000.));
        enginesList.add(new CustomEngine("ACS", 150., 270.));
        final ArrayList<CustomFuelTank> fuelTankList = new ArrayList<CustomFuelTank>();
        fuelTankList.add(new CustomFuelTank("Tank1", 500.));

        // SHAPE
        
        final CustomParallelepiped parall = new CustomParallelepiped(4.0, 1.0, 2.0);
        CustomVehicleSurfaceModel vehicleRefSurface = new CustomVehicleSurfaceModel(parall, null);

        final double cd = 2.0;
        final double cl = 0.;
        final CustomAerodynamicProperties aerodynamicProperties = new CustomAerodynamicProperties(vehicleRefSurface, cd, cl);

        final CustomVehicle vehicle = new CustomVehicle(dryMassProperty, aerodynamicProperties, null, enginesList, fuelTankList);
       
        veh = new GPVehicle("My Vehicle", vehicle);

    }

    public void display() throws GException {
        generic();
    }

    @Override
    public void generic() throws GException {
        put(veh);
    }

    public void read() throws GException {
        generic();
    }

    public void write() throws GException {
        generic();
    }

    /**
     * @param args
     * @throws OrekitException 
     */
    public static void main(String[] args) throws OrekitException {

        PatriusDataset.addResourcesFromPatriusDataset() ;
        
        TestGPVehicleWithInit test = new TestGPVehicleWithInit();
        //GFrame frame = new GFrame("Vehicle", test);
        GPanTest frame = new GPanTest("Vehicle", test, "Vehicule.xml");
        
        frame.display();

    }

}
